package org.apache.bcel.classfile;

import java.io.DataOutputStream;
import java.io.IOException;
import java.io.DataInput;

public final class ConstantClass extends Constant implements ConstantObject
{
    private int nameIndex;
    
    public ConstantClass(final ConstantClass c) {
        this(c.getNameIndex());
    }
    
    ConstantClass(final DataInput dataInput) throws IOException {
        this(dataInput.readUnsignedShort());
    }
    
    public ConstantClass(final int nameIndex) {
        super((byte)7);
        this.nameIndex = nameIndex;
    }
    
    @Override
    public void accept(final Visitor v) {
        v.visitConstantClass(this);
    }
    
    @Override
    public void dump(final DataOutputStream file) throws IOException {
        file.writeByte(super.getTag());
        file.writeShort(this.nameIndex);
    }
    
    public String getBytes(final ConstantPool cp) {
        return (String)this.getConstantValue(cp);
    }
    
    @Override
    public Object getConstantValue(final ConstantPool cp) {
        return cp.getConstantUtf8(this.nameIndex).getBytes();
    }
    
    public int getNameIndex() {
        return this.nameIndex;
    }
    
    public void setNameIndex(final int nameIndex) {
        this.nameIndex = nameIndex;
    }
    
    @Override
    public String toString() {
        return super.toString() + "(nameIndex = " + this.nameIndex + ")";
    }
}
